(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     52232,       1068]
NotebookOptionsPosition[     50838,       1017]
NotebookOutlinePosition[     51181,       1032]
CellTagsIndexPosition[     51138,       1029]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Computational Exploration : Electrons in a Well of Finite Depth\
\>", "Subtitle",
 CellChangeTimes->{{3.56357452331292*^9, 3.5635745268021197`*^9}}],

Cell[TextData[{
 "In this computational exploration we will find the energy levels of an \
electron in a well of finite depth graphically. The objective is for the \
reader to familiarize himself/herself with some basic ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function, which we actually used to generate many plots throughout the \
book.\n\nGiven a value for a given value of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Alpha]", "=", 
    FractionBox[
     RowBox[{"2", "m", " ", 
      SubscriptBox["V", "0"], 
      SuperscriptBox["a", "2"]}], 
     SuperscriptBox["\[Saturn]", "2"]]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "we want to find the zeros corresponding to equation 18.32. These zeros will \
correspond to the energy levels of the electron in the well.\nLet\
\[CloseCurlyQuote]s then start by determining the value of \[Alpha]. We will \
think of an electron (mass 9.1 x ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", 
    RowBox[{"-", "31"}]], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "kg) and a barrier of 5 eV (which is equal to 8 x ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", 
    RowBox[{"-", "19"}]], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "J). The well will have a width of 1nm. As a result we get"
}], "Text",
 CellChangeTimes->{{3.5635745365776787`*^9, 3.563574641568684*^9}, {
  3.563574693314644*^9, 3.5635747181140623`*^9}, {3.563574753901109*^9, 
  3.5635747986366677`*^9}, {3.5635748659435177`*^9, 3.56357488627168*^9}, {
  3.563575058792548*^9, 3.56357510113297*^9}, {3.5635761213593235`*^9, 
  3.5635761670339355`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Alpha]", "=", 
  FractionBox[
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{"9.1", " ", 
      SuperscriptBox["10", 
       RowBox[{"-", "31"}]]}], ")"}], 
    RowBox[{"(", 
     RowBox[{"8", " ", 
      SuperscriptBox["10", 
       RowBox[{"-", "19"}]]}], ")"}], 
    SuperscriptBox[
     RowBox[{"(", 
      SuperscriptBox["10", 
       RowBox[{"-", "9"}]], ")"}], "2"]}], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1.05", " ", 
      SuperscriptBox["10", 
       RowBox[{"-", "34"}]]}], ")"}], "2"]]}]], "Input",
 CellChangeTimes->{{3.563576081129022*^9, 3.5635761027032557`*^9}, {
  3.5635761736103115`*^9, 3.5635763098031015`*^9}}],

Cell[BoxData["132.06349206349202`"], "Output",
 CellChangeTimes->{3.5635763127092676`*^9}]
}, Open  ]],

Cell["\<\
With this result in hand we can make plots of the two sides of equation \
18.32. Let\[CloseCurlyQuote]s start with the right-hand side. We will use the \
function Plot. Its first argument is the function to be ploted, while the \
second argument determines the independent variable and the limits of \
evaulation of the plot.\
\>", "Text",
 CellChangeTimes->{{3.563576323825904*^9, 3.5635763543836517`*^9}, {
  3.5635764138970556`*^9, 3.5635764190553503`*^9}, {3.5635767053517256`*^9, 
  3.5635767459250464`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"2", "/", 
    RowBox[{"Tan", "[", 
     RowBox[{"Sqrt", "[", 
      RowBox[{"\[Alpha]", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", "x"}], ")"}]}], "]"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", ".0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4608374423371162`*^9, 3.4608374662272463`*^9}, {
  3.563576381680213*^9, 3.563576411426914*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVznk41IkfB/BxRghNjnGfpdpIrkh9PqYhZxRSUluOyNG02KhVCqkcUemX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     "]], LineBox[CompressedData["
1:eJwVkHk81PsXxofE2Heyz9iKhrpIizifSolkuSgqES7FdS3pZr1aJDVUN26b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     "]], LineBox[CompressedData["
1:eJwVUXk0lesb5XQMmY95Ko4pikqliDwviWsIkTQgXEPKRaUMUVJu3EqGriuJ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     "]], LineBox[CompressedData["
1:eJwVUXs01HkcnRg73u8UEik2kkdtNlt8fsluDMuabdLLsoXGs7KVZHaTR6eo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     "]], 
    LineBox[{{0.7012038907833954, 11.645735500298395`}, {
     0.7012061257499145, -11.175444698159666`}}], 
    LineBox[{{0.9252787725763447, 11.645735500298395`}, {
     0.9252842884984503, -11.175444698159666`}}], 
    LineBox[{{0.3276795637298141, 11.645735500298395`}, {
     0.3276798129235512, -11.175444698159666`}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0., 1}, {-11.175444698159666`, 11.645735500298395`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.460837467358878*^9, {3.5635763990492063`*^9, 3.5635764121379547`*^9}}]
}, Open  ]],

Cell["\<\
Now, let' s do the left-hand side\
\>", "Text",
 CellChangeTimes->{{3.563576421960517*^9, 3.563576430098982*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Sqrt", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "x"}], ")"}], "/", "x"}], "]"}], "-", 
    RowBox[{"Sqrt", "[", 
     RowBox[{"x", "/", 
      RowBox[{"(", 
       RowBox[{"1", "-", "x"}], ")"}]}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.460837470262184*^9, 3.460837501123396*^9}, {
  3.5635764379234295`*^9, 3.5635764394415164`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVjmk8FGofQAczGpNlZqyVkpRyUeqWaor/c0sUWpAsFyHKUlEKKUlFi6QV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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0, 1}, {-6.286755106510654, 6.143122151348469}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.460837502022234*^9, 3.5635764397585344`*^9}]
}, Open  ]],

Cell["\<\
Finally, let' s plot them together. We can do this by putting the two \
function arguments between {} in the Plot function.\
\>", "Text",
 CellChangeTimes->{{3.563576443485748*^9, 3.5635764493040805`*^9}, {
  3.5635767498292694`*^9, 3.5635767640110807`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", "/", 
      RowBox[{"Tan", "[", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"\[Alpha]", " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", "x"}], ")"}]}], "]"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "x"}], ")"}], "/", "x"}], "]"}], "-", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"x", "/", 
        RowBox[{"(", 
         RowBox[{"1", "-", "x"}], ")"}]}], "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.563576460685732*^9, 3.5635764753015676`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVjnk81Pkfx2cwIixjcoxbq13lJ+WM8P6YJGcpJEce5c5gWqyjVQpRjmVb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     "]], LineBox[CompressedData["
1:eJwVkHk81PsXxofEMJN9yT5aFE3LRaorzqdSIllCcUuEqNxuSDfrbdOkhro3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     "]], LineBox[CompressedData["
1:eJwVUXk4lfkf5XYt2a89lF0ULdNG5PNN0qBQGCpuGDTKINmjpEyMyNJICFlS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     "]], LineBox[CompressedData["
1:eJwVkXs01GkcxifGjvs9uZtIJ9eozckW36lUDCWzpItiLUJIusilEqNTVGw7
KZduK1MrISNKzv7ejRClRHIrci/N+5oSGZrZ2T+e8/zzOc95zvMsDj7ACZWj
0WgBMv3vF0yFHj1fhLBmTASfRUzEcd2XajUlBIUcl9mSv5nokqFRGH9aCPal
RuVHbZioa7rVw2JWCCrJHL/ifWZoT5mTlolECO1Ulu+NEhNUteu7+isahszr
muN6rcZI/aca1TR5DK4fqtLaxEYIBbgoflTE8NDTavZhnCHSV5QqFKhguN2j
dCuq1gAdFCB5b3UZXxKsH61ugMyV3aSVOhhS0+RLdJ8tQokPFH7s08Pg37U0
/7HDItQe1Cg2NMDQ8s7aueSaHuJWs6dTTGX5zWl93ZkL0WiIj9DLCoOe4doK
k790kKumzoTUBkN9kGked4UOuvy4Y7zCHsNWU9WBpw3ayF17x7D+zxh234uZ
kRdroWJqb++wK4b8K860iNOaSG4/s/vyOgzbZNhJB020W2+wk+2GwfIKd6FT
jQZSjQ59Xe6Bgd6rWNKRqI5iDKOeJfti4EheSkfsVVHDU7vG5f4YksTi2Mgi
FWR2kNQP7sTgHNKJw8xU0KvGOOQeiGHYLl7V0UQZrTiSUK0biUEtYNx5+1pF
lMFc86AxCsP15V7Mt80MNNQyX5F4AINXkNGqtt0MxDNPKR04jMFipw67lfsT
mnl5uqjkJAaP+5afEibpaFuSe2FgKoau6bJ892w6urNU+aZ2OgZvQb3KmCMd
7Tp+vuBYBobn1lyBd6I8qrXm/el2CQMjnB9kZiqHUtJvnuorxhCf2hG63ktK
qcUz2L/dw1Ajrdke/kRC5YVHa4+WYbgEb3L9fpFQAk/nQlIp+9Or9pvn8h/U
qFZbvRyFoTmHZm1tO0d5XqMpWrVjKFVXFknDZii96sALR+YwOJw3ulOWN0kV
3nm6XfwDA22AvWd65STlkGdjdpJGoGiDykRGPqE8js+UnVEgMPR4LgIpYCp5
Q1ZbvgaBCJ2Q2PThT9Tgy390n1gQSEmKi+RQw9S9cZN8dS8CJ4cyX4yotFFn
rqYHvd9K4KqL1g3fa61UCEdoWepDgOIts+UzWyjj2tryLf4EokSc1i69eioj
a3fDuWAC+nbfPfiET4W51WUGhBL4Y7pTNJibTa2ftfaxDScgznQ0ju47C7PB
4t6WaALl9meTap0qINwpV6ScQADffYfbrjSB2wStuieJwBnHZB7tynMwuxGe
XHyCwIMlIff6OK+gU2k1g80l0CAyST98rAM2vus0PptFwHCFt3/TynfAvOg6
uOMigTCWot+CE/0wv4l/e9klAp3heyShnwagsvzIiqY8AkpVEUMivyEw5+q6
M/gE+utCV6llj4NkdbLa2zsEOGGI6zLzEbqFQ6/5d2X7FCy0nouYgGx/wZ5N
9wmwsjZ2so9iiFI1stCrJBCfdvWNudIkuP+bOj5SRYA5stPHr38SpNacQ+m1
BBgJgcmPb3+Bnv5Hq/0oAi97CteT/K9QxVssWfKEgFMtfyKkYAouepytm6on
gIRbBzKKv0GMZPJMfSOB1NjsLLWmaWALdmzlNRM41DfWMjI9A5bhSCfkBYEB
w6ij+51noa8t65p8O4HNXc5lfgrz8PD0zO/tbwjsjzGI9875Abw1gVaFXQQG
011zM9lSiJ1swHG9BIhT0RY2j8byLLKvXP+eQEz5+bGwggWspbtyErQ/yP5s
0hQsqpNjyWlIXAeHCGh2PM8RaNBZ7+tC6RWjBB6tY/3KOafAqjn24tmpjwSq
9tvUeW5msHLsVmX5fCYw27Gkt9tPiXVwsMB3MZH1v1B9Q7VbheV1mW4oEhH4
PGKp+5WhwVrmFdWPpgjkbO5cm1KoxaIv6LiVPUOg+HDNVJ1AlzXwYE1kkJjA
XrrtnG2dASuaqyPNnSeQ2zt1+bDvYtZ/Z7/2vQ==
     "]], 
    LineBox[{{0.7012041827030586, 8.664952038421506}, {
     0.7012058610406222, -8.47250556781693}}], 
    LineBox[{{0.9252794930373045, 8.664952038421506}, {
     0.9252836351929872, -8.47250556781693}}], 
    LineBox[{{0.3276795962781996, 8.664952038421506}, {
     0.32767978340906084`, -8.47250556781693}}]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJwVlGc4Ffwfxo99nMc4x947Ekk9Uim+v6dEoYE8xoMQERUiyahUVCQjIYSs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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0, 1}, {-8.47250556781693, 8.664952038421506}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.563576475645587*^9}]
}, Open  ]],

Cell["\<\
We are now ready to begin our graphical search for roots. Let\
\[CloseCurlyQuote]s zoom in onto the first root. In order to do that we\
\[CloseCurlyQuote]ll just change the range of the plot from [0,1] to \
[0.15,0.25].\
\>", "Text",
 CellChangeTimes->{{3.5635764865252094`*^9, 3.56357655488612*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", "/", 
      RowBox[{"Tan", "[", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"\[Alpha]", " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", "x"}], ")"}]}], "]"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "x"}], ")"}], "/", "x"}], "]"}], "-", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"x", "/", 
        RowBox[{"(", 
         RowBox[{"1", "-", "x"}], ")"}]}], "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0.15", ",", "0.25"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.460837562761133*^9, 3.460837593555361*^9}, 
   3.563576522956293*^9, {3.5635765572832565`*^9, 3.563576560876462*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVkGs01Hkch2eGmZg/lkixrEutSzFLRjbS91fWqmytGEqMZlmXdV9syOoi
tU6TKMspnYxbbW1SHGRaW6MxxpjLv9ioJGmLGJcxuYzLsPbFcz7nOZ93j1V4
kn8kiUAg7F/l/y20KXZzceHDpb2FV5xM5XCGfvQEnc6HP+zIDu/M5XBst73A
1ZUPLq168iIrOYSG/e3/tRsfiHHL8jk7OdiVfEjw9OADtrxxodVNDjzytmof
Lz5c6KIdCAuUw+T7Hv3QAD5cO9hEbS6Uw4GqDaO5qXz405l6dmrNGHhUqq8D
lw94xAOvEZ1xaNfxCw9Z4MOG9Ne2jzQmIG0U2+rk3gbXOmPru1UT4L/PXiPx
ZBtQ1F4KGw0FSNc1vNfhtYF1wcXGmhwFpEeUC40oAjjJfmkzpDcF3ptmG5/v
E4DMp/JFY+kU3PfjNsydF8BIX82YpYUSfFf6G3KeCkDKyl0i1CnhjEmyINGg
HYbZ4m8SPT7BwM24QcOD7dBkLEkNFHyC2KaOZauSdnh0NfBVHnMaipyLHC71
tAO6GI4ZTUyDnPY45CczIRgWtFncyJ+BKA6jZIElhNgKz+IjjrNwMuvQ4Fi5
EN48P5VvL5gF4cu/HPcMCSFgvD3HOGEO7lbln9e07QBfoWkepquCJ5O8j/YJ
HbCWPcXWfaSCxVqmv1Z9B3g8niHxkubh2ctoiY+yA5LfbpE4myxAz7luH4Wb
CHZK6Qqz5wuQyanpns8QwbeGy9ymvEWALZOxLc0iKFMEZQ3sWALX7UUaH9Ui
MEW3r1qS1dBRX12TtrMTVOWs7bw2NbBr1x+Kze2ETcRPr/69ugw/m0/rmIg6
IegOs3kmeQVm5jy77bTFIDpmNX3WgoBuMUZKKw6Iwa9X/CLhMgGpzEipWQVi
WKSxXLsJRBR/ODdIDxdDRTXN3iaZiD4zjvGgGkngH62u3rIxIvIDrlM0QwKc
qDDt6B9JiDcaZ+tYKoGl+mtHMkdJSEa8QGP0SYBaqowciNNAK+x1u+ifS4Fz
vI48NqGBjl4hBGazpBDpOXhTN0cTMfWDM20rpHCvL3xvsD4ZnacactyHpSBe
+0oZdJ+M+tK3PaU4yKCl+DDxbgAFifyEBvR4GVx3KA+lKClo+A6X0Vkng7ra
qaWm6jWoMsXkVqtSBkPHxq2L/LXQ6Zp3lJStODCY6ifrNbVRQYxuNDsdh41p
yhN0qTZyL7zRS27GQZ1t4JRxiYocUlx5X3JxcPzuY4TqdyoyZwhueT/EYTYk
cl/mFSoibPiQebYFB0UlcsrmUJGQs8mM3LrqXpSo/LtUxLhXxdLsxGH9bxm1
uIiKEmUVI6TXOHDDupj9JAyx7jt3WffjcOHZYEgaBUMHL7c+3P0Gh/geTyMd
KoboQYPsnLc40Ip6GzwNMLTYb0kjfcDBW5nVctsCQ3njnBTiBA53IraZ39iB
oeP4VyFWkzjsj3nW74MwFF/32GuXAofdfY2hci8Mff/LgNFpJQ4Cl7ASui+G
jNVfPCDM4ZC4ZS/haTCGtAZqOZaq1T4Bvg8zmBia5+3MQ/M4ZLuU061/wNDr
3LDgU4urv3JPXHoMhmRRE7vKl3AwOmdptzEeQ7w9Jzbz1DiU7fC/iSdhqH6z
nuHb5dWe7pZDv6ZiqEqnbHFlBYfiNsnw5nQM/QehulBb
     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJwVznk41HkAx/EhPBZZFZVCacu1Q4gKm49Ky6PWMs2mVpglR8K2JGk2OkiP
o5Km3fWocVTjKUdETOlpaszhml+tzSYJGx0S9juOYYbZ9o/38/r3bRn+MyNS
k0ajffe5/71oxdm0YYMQjv7aK5pD1DjjEpbm4iIE/cdEefh+NY5usxW5ugpx
r7n2jUawGvtDHzI2bxIi+a8SXa+9athcGYrf4iFE7/OhiIcMNQTaG6/7bBci
6mVCSJOPGmODXUb7dwuRWTji0+akhn/Z8uGMJCHeH8wLouuo4VE6dxV8IbzZ
WkJR+TzEBgHhwbNCpK3OKZplzOPIsL6zo3szjibp8Kxp82D42S5ISG+GsbN9
fR1vDh0mdYMGgmaU1Kvr4vfMISWiWGKsI4L9Iu/r1WoVdqydqn/uJ0L+4VBh
120V7gTw66azRZA29lwUhqqwU91bd/qpCCY8Hj/CQIUzpodFCYvEuDn/qYoj
UKLv5qGBJYFiOEinJN4pSsTek85bXhGj9yv2ZpmNEgVOBfT8LjG42tZrOf2z
+OjwKPigmQRlt/QnggpmEcVlXpllSZDhcNci13cW6eyggZFiCfQ/8TjVC2Yh
6X5g7/tWAvmLA1GEP4PKsrxsLWspXlaub1Qlz+DJmOC9bbwUUd9a2Hvbz0BZ
FcLQrZUiJlmsI36rwLPu6HYfIoVZQ+lg2w0Fus52+oxvasFcyo5iB5YCqdyK
zpljLWgWF06RVQrg67HYpsYWDKQXNFQMTMPVrWDB+7kWXGU9yOu/Ng1p7fWK
I56tyD2WZ7jlp2nkVC0Lis1oRZow6TB91TR+MZ8wMG1pRZKvJFa/bwqT01s6
bb5oQ66e2W+9ZVMoZ34oLPFvgwlZHB1yYAoKM80k9oU2MB/oLqu3nULc3ow9
hlQbgr2KuaLxSXy5NMZDz7gdpVltx4ruTiIAfMdoZjvEKy9fMmdPQjB8yNq+
sB078zvbUz0nIdPIdWD2tOM8e7dNjM4k1DkmW11WdmDDeiPVv9QEwn6n/XCC
1QFLP7pHPGcCIUb7Uq1LOuC3zs2OETaBbL0lXPd3HYj6w8vXY90EelI2PtWh
y7DCJelN04gcLQGSRS5xMiiViu5TjXK8u81nttbIMN6udS7spByliablj4kM
cqva0bhdcpyq+Ecn0ZnCUSMF+6OpHBdiFkbnpFDwNG/ic94QuF+88bd2I4UJ
I1q2fw0BPdFVsI5P4cCwWJ5wh8CcKSrfcZ/CLvbZyAvVBLTlQ6mZTRTcnoyw
nlYSSLhrzbQfU+js92pg3CJgVpextFop1OSFDewtI0iQlXzQfEXhReU3Voc4
BKw7Tn+u6aWQnsXLy71MEHjp8f1tryk8cZOrKgsIXPYM5Jzup2DhbCcfzydQ
9q520Byi4P5QwzPlPMG5T9xEjdHP/69rdmVmERyn1gdbjlFgFj1z4p0liKt5
tH3rOAXHSLFFSybB98l9xqcIBakV3WhhBsHSOYsG2jSFwJ7OAM5JAt2+Ku5q
BYVWVtaRhnSCGYHnOa8ZCgcX6xV3pxG8ygjdd1JJIcHguKHFCQJZ1OjWYhWF
ja8jA71+JRD4ptkJ5igMjpoXhbMJau0Ml/TPU4g4UzKacZygzOCaUq2mUNU/
5stLJfgPFxJ9KQ==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0.16, 1.},
  PlotRange->{{0.15, 0.25}, {0.8469470004804852, 3.433187304436226}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.460837580180293*^9, 3.46083759607673*^9}, 
   3.563576561377491*^9}]
}, Open  ]],

Cell["Let' s keep going down", "Text",
 CellChangeTimes->{{3.56357656468668*^9, 3.563576568245884*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", "/", 
      RowBox[{"Tan", "[", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"\[Alpha]", " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", "x"}], ")"}]}], "]"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "x"}], ")"}], "/", "x"}], "]"}], "-", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"x", "/", 
        RowBox[{"(", 
         RowBox[{"1", "-", "x"}], ")"}]}], "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0.18", ",", "0.2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.563576577821431*^9, 3.563576580056559*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVznk81Hkcx3HR8Yi2dXTsg9qcWxErV47J2z4mXcOy1iqVazNoK0aplIgO
dNKalsnIUSk1q6W1HlFMYn6/X9tFoRElY0cHW+ox59e2+9s/Po/34/l4/fOx
+TEljG9oYGAQzN7/+9r3cOpyYwq1nUx892YVso0tlALWWl+fLF68CnP7Kjdc
YH0lar3oNuvAva1cExMKzTOqn/zKV6GyUT9bznpWS3ZMbqIKkR6pTWmfUcjp
CpAt26oC4xxtJDGlEG287mnpDhVqrL3PWM6lMDzV23xLjgozmtxuzHCgsE4w
i19SqcLGh/0rzd0oeHyrHGhrVSGLThL0+FNwrZ8jSB1QYcUuv7PXgijMdwny
vPOPCuqyW87iSLYvMNtgPE8N3r7c22WJFDJ/qxjTc9RI8106HrWLwl9CxciO
KDWO7T5+bOlBCl6etk59GWpwE5bYWxZSCH1SoPkgVuNV5/6Fc8ooXDSpM9Q2
qxFnc032qIbC6T+zYrP61Mi0X5RQ0UihZ+YHfgtR48j50JRD7RS4Lql7hi01
cO1pTc/oovB5o9/wXY4G10ZNv3QbpCBR2Lt5RWtgdcDMeWKUwtrT7w1zMjVw
7FjPeaancGsjlMJyDRzyQhruT6PxTLxw+pFWDe5MnHDpnk0jrL0gNHBIA88I
CbfUju2e2wOOTtaiyCmjLc2VRr75u9NV9loIfy/8ZrM/jX9fh/udWaXFwRs/
OPJ5NJ7H8OSRSVpwqyZqHdbTqG1yXFmar8Vl/zfuhE/j4VjvitarWugi8myH
d9AYmdbnXXtPizHbrWZD2TSqz1dtynuvRUOXq/jcKRrWi8LiXlrosOXTxcLk
Uhqr727QffLQQToQd+T7GvafZhuJaaQORj73Fbw/aETVlXOH9ulgmW753PAO
DcH0pBhnsQ5Pfqp9+uARjRf1D/J3S3XIkI9zagdoXO/ZZpo+pEMHyaisektj
1XlZ/4FpehBRQ8oVLY09FcWLOY56TJnXKRdMYdDT/neoIEiP+u/cVwRZMBAP
Hg5oSNWDZxT4hZ81g8ltWlm1UI+8pLJRfxcGH8282+ua9Ciu6900icMgLthm
jc+gHsLdt716VzN47WdrzDci8Hg3btoWweASIytqWEwgVXSGSzczUKZpvq4O
JrC+WeSRKWAgFO+dZJJKYLdaPCski4GnLF5XXkxgHhoe7XGcgcLONvNeM8Fl
xfKP21mH7UqOT75JgD0L8y+x/uBiEWJ6i2DbOX2d5QkGOSkJLuEtBNRoxZRJ
JxkEL/Oe3S8l2H90THL/FANeWs2h0Q4CZVsuSfiZgdUFavjzR2yPEBRWsM52
2rKsnrXFm0iHPta97YknwzsJAsycQ4KLGIja9nNFXQSlMY+r3IUMDhkZP7Xt
JgidWLDW4BcGb/ldVV59BCMF01/4sJacjXCSs86y+7hzJ+v5Pr6NGc8Irq6V
lSlZc9ZYy6X9BFNF28bvFTM40LU1kPeCQLwkIndqCYNKwbtXY6zdpbAKYG19
8XFB4SBB7Ih54HXWksSWke6XBJp9E/JR1iMBHSXpQwSnZiqTvxIxmLPKOdhK
QWBf9dAolnVTuXpyC+tmzxslItYnBDbS2GGC/wDW33w/
     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1HtQjXkYB/CjM5UtTBctU+5Oatuiy2Fdcr7VqdZIU3E6k6SNZAs5J6Ui
YtFNl22UdFWOqGhq0ha1axVb7/u2S2oVsS0rE7osh/B73w72t38888xnvn89
zzzzLNyu2hihJxKJfGn931+uPhGz1oiBZbPrRGCVgKNG5sNqakWriWwu9ayH
54IrqT3FB9KfXRTgdeCG3NiYwWqlwfxY6nNXBYsB6tQL5ptyLwjYLI1pjZvO
YMj0fX/XeQGcQ6i41oTBnchbvm4VAmoWrDxtOYuBtLjrvX2RgGmtzi3TrBno
zd6VOJghYEv3X95mzgyaGTt1SZKAZDZS3S9jYBDSbXopWoDn/jXF9RsYJC4z
kOeHCnhfdt2hdDODzmJRYYa/AJ+Dqe1l3zMwLbdYFuIuIG61k3brfgbGfYoX
R5wFnIzPPOl0jIH9SJWqViJAvtNeYpnLINL2hPc1CwEveg7ZfFnGIOWgYcvv
hgK2LazvvFvDID790gsHgcdhie3OiqsMKsPTw2JGeaSc91cd/41BR5Zc1jrI
w7H/RmJSL4N/Cr4SD9/hUT9mMs/5CYN3O6byYW08rI6YOujG6D68860eX+Fh
1xHk+khgEK1SWnlU8rBO82u6bcjCdVQkqSrgcUuXtbTPgoWk0Lf8TRqP5cpa
ecliFp/5YNesAzzyvk66GefIYsUWt2brPTzyf8p1D5exsAtUZFdt5XGsJdAu
wofmY/YSW38eco2uzjqIxZOAWM2EB49q2YjLZASLxmvegZelPHhl2qJn+1i0
1cxqCbXhMb5ot+nToyyi5urufZzNo6nXsfRsDosCfrfXSyMeUZ8u5O4tYRFc
fkXR/ZGgbXBbyqYaFuzGb7SaVwTiVbeHfJpZZH/onaN+SmCZaPm33i2W3lnA
4bQ+gnu76h7cucti9OKEQw5DkDSgda0bZKF+tiYhq5WgYzLpnGaURUhE0PGk
WoLJoibVJcIiCB7ztpUT6M/pGVDrc9he94M49xTBlQAXzw3mHHKSr+9oOEHg
I/aavWYBB+d9TlFMAkFaZNmYbCmH3l5fRU8UwZmG+yFTXDlIe2peS0II8uPb
V9xfx6HxncJ9tx+B9JXW5KaSQ/wS3bIqdzrfUI+iLZyD2bhn3z0pwYJf8qSH
1RyaGzc4rrclWLyudKZfMofXk/XdzZYEZv6KUGkmB0/7IH/zGQTVQ2vfRlO3
RaVpH04nQIJNehX151avPA31nrNCg2UWByFT9cCJmhmr0J+SzUGWkxDlP43g
UMZ47e0cDinfKi9mGxEM30yd3HmKw4jDysyphjRXqnMrqMcb5LK7BgTmI5ut
H1LvGxrUnqF2M3Xw883jsM7j12Ab6pLv/tS45HPoP73UxVufwF83f72ogMPl
rq5Px8UEz3/84vEq6pjqG60+1MmL38bGUreL5Anm1JfXd5YNU3vMfKfV6BEY
FO3R/nGGQ2W0wb/tUwhK7ZWpBoUcijv31mVQu7TByo268miEKoA67LmZVyO1
zPjTmycigg8HdQNj1HF95U3V1DkzhvcuKeIgnuhOVFNLNN3iMOqO8BzXldQ/
L28pLKJOX/iIfjOC/wAl0mjy
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0.18, 1.4000000000000001`},
  PlotRange->{{0.18, 0.2}, {1.3368734299702782`, 1.743256330976723}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.563576580389578*^9}]
}, Open  ]],

Cell["\<\
The first root seems to correspond to an x value of 0.193, approximately. \
Using equation 18.31 we then conlcude that the first energy level, the ground \
state has an enery\
\>", "Text",
 CellChangeTimes->{{3.56357658986412*^9, 3.5635766451392813`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "0.193"}], "*", "5"}]], "Input",
 CellChangeTimes->{{3.563576651555649*^9, 3.5635766578820105`*^9}}],

Cell[BoxData[
 RowBox[{"-", "0.9650000000000001`"}]], "Output",
 CellChangeTimes->{3.5635766598921256`*^9}]
}, Open  ]],

Cell["\<\
Where the energy is given in eV. The reader is encouraged to find the next \
energy levels in a analogous manner.\
\>", "Text",
 CellChangeTimes->{{3.563576662344266*^9, 3.5635766876027107`*^9}}]
}, Open  ]]
},
WindowSize->{640, 750},
WindowMargins->{{4, Automatic}, {Automatic, 4}},
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (November 13, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 158, 3, 77, "Subtitle"],
Cell[728, 27, 1623, 38, 170, "Text"],
Cell[CellGroupData[{
Cell[2376, 69, 678, 22, 56, "Input"],
Cell[3057, 93, 90, 1, 30, "Output"]
}, Open  ]],
Cell[3162, 97, 523, 9, 65, "Text"],
Cell[CellGroupData[{
Cell[3710, 110, 440, 12, 31, "Input"],
Cell[4153, 124, 13076, 224, 230, "Output"]
}, Open  ]],
Cell[17244, 351, 123, 3, 29, "Text"],
Cell[CellGroupData[{
Cell[17392, 358, 510, 15, 31, "Input"],
Cell[17905, 375, 4692, 82, 233, "Output"]
}, Open  ]],
Cell[22612, 460, 268, 5, 47, "Text"],
Cell[CellGroupData[{
Cell[22905, 469, 719, 22, 52, "Input"],
Cell[23627, 493, 16759, 286, 233, "Output"]
}, Open  ]],
Cell[40401, 782, 310, 6, 47, "Text"],
Cell[CellGroupData[{
Cell[40736, 792, 797, 23, 52, "Input"],
Cell[41536, 817, 3895, 71, 238, "Output"]
}, Open  ]],
Cell[45446, 891, 103, 1, 29, "Text"],
Cell[CellGroupData[{
Cell[45574, 896, 722, 22, 52, "Input"],
Cell[46299, 920, 3749, 68, 230, "Output"]
}, Open  ]],
Cell[50063, 991, 265, 5, 47, "Text"],
Cell[CellGroupData[{
Cell[50353, 1000, 139, 3, 31, "Input"],
Cell[50495, 1005, 107, 2, 30, "Output"]
}, Open  ]],
Cell[50617, 1010, 205, 4, 29, "Text"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
